#include "tdsutil.h"
#include "tds.h"
#include "sybfront.h"
#include "sybdb.h"
#include "dblib.h"
#include <unistd.h>

/* info/err message handler functions (or rather pointers to them) */
int (*g_dblib_msg_handler)() = NULL;
int (*g_dblib_err_handler)() = NULL;
extern int (*g_tds_msg_handler)();
extern int (*g_tds_err_handler)();

RETCODE dbinit()
{
       /* set the functions in the TDS layer to point to the correct info/err
        * message handler functions */
       g_tds_msg_handler = dblib_handle_info_message;
       g_tds_err_handler = dblib_handle_err_message;


	return SUCCEED;
}
LOGINREC *dblogin()
{
LOGINREC * loginrec;
pid_t	pid;
char	pidstr[10];

	loginrec = (LOGINREC *) malloc(sizeof(LOGINREC));
	loginrec->tds_login = (void *) tds_alloc_login();

	/* set default values for loginrec */
	tds_set_library(loginrec->tds_login,"DB-Library");
	tds_set_charset(loginrec->tds_login,"iso_1");  
	tds_set_packet(loginrec->tds_login,512); 

	return loginrec;
}
void dbloginfree(LOGINREC *login)
{
	free(login);
}
RETCODE DBSETLPACKET(LOGINREC *login, short packet_size)
{
	tds_set_packet(login->tds_login,packet_size);
	return SUCCEED;
}
RETCODE DBSETLPWD(LOGINREC *login, char *password)
{
	tds_set_passwd(login->tds_login,password);
	return SUCCEED;
}
RETCODE DBSETLUSER(LOGINREC *login, char *username)
{
	tds_set_user(login->tds_login,username);
	return SUCCEED;
}
RETCODE DBSETLHOST(LOGINREC *login, char *hostname)
{
	tds_set_host(login->tds_login,hostname);
	return SUCCEED;
}
RETCODE DBSETLAPP(LOGINREC *login, char *application)
{
	tds_set_app(login->tds_login,application);
	return SUCCEED;
}
DBPROCESS *dbopen(LOGINREC *login,char *server)
{
DBPROCESS *dbproc;
TDSSOCKET *tds;
struct sockaddr_in      sin;

	dbproc = (DBPROCESS *) malloc(sizeof(DBPROCESS));
	memset(dbproc,'\0',sizeof(DBPROCESS));
	tds_set_server(login->tds_login,server);
	dbproc->tds_socket = (void *) tds_connect(login->tds_login);
	/* dbproc->dbbuf[0]='\0'; * initialize query buffer */

	if(dbproc->tds_socket) {
		tds_set_parent( dbproc->tds_socket, dbproc);
	} else {
		fprintf(stderr,"DB-Library: Login incorrect.\n");
		exit(1);
	}

	return dbproc;
}
RETCODE	dbcmd(DBPROCESS *dbproc, char *cmdstring)
{
	/* here is one of those large static buffers that should be malloced 
	** but in the interest of time i kludged :)   */
	strcat(dbproc->dbbuf,cmdstring);
	return SUCCEED;
}
RETCODE dbsqlexec(DBPROCESS *dbproc)
{
	/* printf ("submitting query\n"); */
	tds_submit_query(dbproc->tds_socket, dbproc->dbbuf);
	dbproc->dbbuf[0]='\0';
	return SUCCEED;
}
RETCODE dbuse(DBPROCESS *dbproc,char *dbname)
{
char query[255];
int retval;

	sprintf(query,"use %s",dbname);
	dbcmd(dbproc,query);
	dbsqlexec(dbproc);
	while (dbresults(dbproc)!=NO_MORE_RESULTS) 
		while (dbnextrow(dbproc)!=NO_MORE_ROWS);
	return SUCCEED;
}
void dbclose(DBPROCESS *dbproc)
{
TDSRESULTINFO *resinfo;
TDSSOCKET *tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	if (tds) {
		resinfo = tds->res_info;
		if (resinfo) tds_free_results(resinfo);
		tds_free_socket(tds);
	}

	free(dbproc);
}
void dbexit()
{
}
RETCODE dbresults(DBPROCESS *dbproc)
{
int i;

	/* printf("in results\n"); */
	/* this mallocs a bunch of mem that needs to be freed when done */
	return(tds_process_result_tokens(dbproc->tds_socket));
}
int dbnumcols(DBPROCESS *dbproc)
{
TDSRESULTINFO *resinfo;
TDSSOCKET *tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	return resinfo->num_cols;
}
char *dbcolname(DBPROCESS *dbproc, int column)
{
static char buf[255];
TDSRESULTINFO *resinfo;
TDSSOCKET *tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	if (column < 1 || column > resinfo->num_cols) return NULL;
	strcpy (buf,resinfo->columns[column-1]->column_name);
	return buf;
}
RETCODE dbnextrow(DBPROCESS *dbproc)
{
TDSRESULTINFO *resinfo;
TDSSOCKET *tds;
RETCODE ret;
int i;
TDSCOLINFO *curcol;
int srctype, desttype;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	ret = tds_process_row_tokens(dbproc->tds_socket);

	for (i=0;i<resinfo->num_cols;i++)
	{
		curcol = resinfo->columns[i];
		if (curcol->column_nullbind) {
			if (curcol->column_size==0) {
				*(curcol->column_nullbind)=-1;
				
			} else {
			/* *(curcol->column_nullbind)=curcol->column_size; */
				/* need to dbconvert here and set accordingly */
				*(curcol->column_nullbind)=0;
			}
		}
		if (curcol->varaddr)
		{
			desttype = _db_get_server_type(curcol->column_bindtype);
			srctype = _get_conversion_type(curcol->column_type,curcol->column_size);
			dbconvert(dbproc,srctype,
				curcol->column_value,-1,desttype,
				curcol->varaddr,curcol->column_bindlen);
				
		}
	}
	if (ret==TDS_SUCCEED) 
		return REG_ROW;
	else 
		return ret;
}
int _db_get_server_type(int bindtype)
{
	switch (bindtype) {
		case CHARBIND:
		case STRINGBIND:
		case NTBSTRINGBIND:
			return SYBCHAR;
			break;
		case INTBIND:
			return SYBINT4;
			break;
	}
}
DBINT dbconvert(DBPROCESS *dbproc,
		int srctype,
		BYTE *src,
		DBINT srclen,
		int desttype,
		BYTE *dest,
		DBINT destlen)
{
	switch(srctype) {
		case SYBCHAR:
		case SYBVARCHAR:
			return _convert_char(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBMONEY:
		case SYBMONEYN:
			return _convert_money(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBBIT:
			return _convert_bit(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBINT1:
			return _convert_int1(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBINT2:
			return _convert_int2(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBINT4:
			return _convert_int4(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBFLT8:
			return _convert_flt8(srctype,src,
				desttype,dest,destlen);
			break;
		case SYBDATETIMN:
		case SYBDATETIME:
			return _convert_datetime(srctype,src,
				desttype,dest,destlen);
			break;

	}
	return FAIL;
}
RETCODE dbbind(DBPROCESS *dbproc,
		int column,
		int vartype,
		DBINT varlen,
		BYTE *varaddr)
{
/* this is really fucked up:
1) it ignores most of the arguements 
2) it assumes everything is a string
3) it uses a fixed length (255 byte) array in dbproc->resinfo->columns to store the varaddrs
MEANING: don't consider this implemented by any means. This is a total kludge
*/
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	colinfo = resinfo->columns[column-1];
	colinfo->varaddr = (char *)varaddr;
	colinfo->column_bindtype = vartype;
	colinfo->column_bindlen = varlen;
		
}
void dbsetifile(char *filename)
{
	set_interfaces_file_loc(filename);
}
RETCODE dbnullbind(DBPROCESS *dbproc, int column, DBINT *indicator)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	colinfo = resinfo->columns[column-1];
	colinfo->column_nullbind = indicator;
}
DBINT DBCOUNT(DBPROCESS *dbproc)
{
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	return resinfo->row_count;
}
int dbcoltype(DBPROCESS *dbproc,int column)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	colinfo = resinfo->columns[column-1];
	return colinfo->column_type;
}
char *dbcolsource(DBPROCESS *dbproc,int colnum)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	colinfo = resinfo->columns[colnum-1];
	return colinfo->column_name;
}
DBINT dbcollen(DBPROCESS *dbproc, int column)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	if (column<1 || column>resinfo->num_cols) return -1;
	colinfo = resinfo->columns[column-1];
	return colinfo->column_size;
}
DBINT dbdatlen(DBPROCESS *dbproc, int column)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	/* FIX ME -- this is the columns info, need per row info */
	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	if (column<1 || column>resinfo->num_cols) return -1;
	colinfo = resinfo->columns[column-1];
	return colinfo->column_size;
}
BYTE *dbdata(DBPROCESS *dbproc, int column)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	if (column<1 || column>resinfo->num_cols) return NULL;
	colinfo = resinfo->columns[column-1];
	/* FIX ME -- check for null value */
	return colinfo->column_value;
}
RETCODE dbcancel(DBPROCESS *dbproc)
{
	tds_process_default_tokens(dbproc->tds_socket,CANCEL);
	return SUCCEED;
}
void dbprrow(DBPROCESS *dbproc)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;
int i,col,collen,namlen,len;
char dest[256];
int desttype, srctype;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;

	while(dbnextrow(dbproc)==REG_ROW) {
		for (col=0;col<resinfo->num_cols;col++)
		{
			colinfo = resinfo->columns[col];
			desttype = _db_get_server_type(STRINGBIND);
			srctype = _get_conversion_type(colinfo->column_type,colinfo->column_size);
			dbconvert(dbproc, srctype ,colinfo->column_value, -1,
					desttype, dest, 255);
			
			/* printf ("some data\t"); */
			printf("%s",dest);
			collen = _get_printable_size(colinfo);
			namlen = strlen(colinfo->column_name);
			len = collen > namlen ? collen : namlen;
			for (i=strlen(dest);i<len;i++)
				printf(" ");
			printf(" ");
		}
		printf ("\n");
	}
}
int _get_printable_size(TDSCOLINFO *colinfo)
{
	switch (colinfo->column_type) {
		case SYBINTN:
			switch(colinfo->column_size) {
				case 1: return 3; 
				case 2: return 6; 
				case 4: return 11; 
			}
		case SYBINT1:
			return 3;
		case SYBINT2:
			return 6;
		case SYBINT4:
        		return 11;
		case SYBVARCHAR:
		case SYBCHAR:
			return colinfo->column_size;
		case SYBFLT8:
			return 11; /* FIX ME -- we do not track precision */
		case SYBREAL:
			return 11; /* FIX ME -- we do not track precision */
		case SYBMONEY:
        		return 12; /* FIX ME */
		case SYBMONEY4:
        		return 12; /* FIX ME */
		case SYBDATETIME:
        		return 26; /* FIX ME */
		case SYBDATETIME4:
        		return 26; /* FIX ME */
		case SYBBIT:
			return 1;
		/* FIX ME -- not all types present */
		default:
			return 0;
	}

}
void dbprhead(DBPROCESS *dbproc)
{
TDSCOLINFO * colinfo;
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;
int i,col, len, collen, namlen;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	for (col=0;col<resinfo->num_cols;col++)
	{
		colinfo = resinfo->columns[col];
		collen = _get_printable_size(colinfo);
		namlen = strlen(colinfo->column_name);
		len = collen > namlen ? collen : namlen;
		printf("%s",colinfo->column_name);
		for (i=strlen(colinfo->column_name);i<len;i++)
			printf(" ");
		printf(" ");
	}
	printf ("\n");
	for (col=0;col<resinfo->num_cols;col++)
	{
		colinfo = resinfo->columns[col];
		collen = _get_printable_size(colinfo);
		namlen = strlen(colinfo->column_name);
		len = collen > namlen ? collen : namlen;
		for (i=0;i<len;i++)
			printf("-");
		printf(" ");
	}
	printf ("\n");
	
}
DBBOOL DBROWS(DBPROCESS *dbproc)
{
TDSRESULTINFO * resinfo;
TDSSOCKET * tds;

	tds = (TDSSOCKET *) dbproc->tds_socket;
	resinfo = tds->res_info;
	if (resinfo->rows_exist) return TRUE;
	else return FALSE;
}
/* STUBS */
RETCODE dbsetdeflang(char *language)
{
	return SUCCEED;
}
int dbgetpacket(DBPROCESS *dbproc)
{
	return 512;
}
RETCODE dbsettime(int seconds)
{	
	return SUCCEED;
}
RETCODE dbsetlogintime(int seconds)
{	
	return SUCCEED;
}
DBBOOL dbhasretstat(DBPROCESS *dbproc)
{
	return FALSE;
}
DBINT dbretstatus(DBPROCESS *dbproc)
{
	return 0;
}
RETCODE DBCMDROW(DBPROCESS *dbproc)
{
	return SUCCEED;
}
int dbaltcolid(DBPROCESS *dbproc, int computeid, int column)
{
	return -1;
}
DBINT dbadlen(DBPROCESS *dbproc,int computeid, int column)
{
	return 0;
}
int dbalttype(DBPROCESS *dbproc, int computeid, int column)
{
	return 0;
}
BYTE *dbadata(DBPROCESS *dbproc, int computeid, int column)
{
	return "";
}
int dbaltop(DBPROCESS *dbproc, int computeid, int column)
{
	return -1;
}
RETCODE dbsetopt(DBPROCESS *dbproc, int option, char *char_param, int int_param)
{
	return SUCCEED;
}
void dbsetinterrupt(DBPROCESS *dbproc, int (*ckintr)(),int (*hndlintr)())
{
}
int dbnumrets(DBPROCESS *dbproc)
{
	return 0;
}
char *dbretname(DBPROCESS *dbproc, int retnum)
{
	return NULL;
}
BYTE *dbretdata(DBPROCESS *dbproc, int retnum)
{
	return NULL;
}
int dbretlen(DBPROCESS *dbproc, int retnum)
{
	return -1;
}
RETCODE dbsqlok(DBPROCESS *dbproc)
{
	return SUCCEED;
}
int dbnumalts(DBPROCESS *dbproc,int computeid)
{
	return 0;
}
BYTE *dbbylist(DBPROCESS *dbproc, int computeid, int size)
{
	return NULL;
}
DBBOOL DBDEAD(DBPROCESS *dbproc)
{
	return FALSE;
}

int (*dberrhandle(int (*handler)())) ()
{
      int (*retFun)();
      if( g_dblib_err_handler )
      {
              retFun = g_dblib_err_handler;
              g_dblib_err_handler = handler;
              return(retFun);
      }
      else
      {
              g_dblib_err_handler = handler;
              return NULL;
      }
}

int (*dbmsghandle(int (*handler)()))()
{
      int (*retFun)();
      if(g_dblib_msg_handler)
      {
              retFun = g_dblib_msg_handler;
              g_dblib_msg_handler = handler;
              return(retFun);
      }
      else
      {
              g_dblib_msg_handler = handler;
              return NULL;
      }
}

RETCODE dbmnyadd(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2, DBMONEY *sum)
{
	return SUCCEED;
}
RETCODE dbmnysub(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2, DBMONEY *diff)
{
	return SUCCEED;
}
RETCODE dbmnymul(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2, DBMONEY *prod)
{
	return SUCCEED;
}
RETCODE dbmnydivide(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2, DBMONEY *quotient)
{
	return SUCCEED;
}
RETCODE dbmnycmp(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2)
{
	return SUCCEED;
}
RETCODE dbmnyscale(DBPROCESS *dbproc, DBMONEY *dest, int multiplier, int addend)
{
	return SUCCEED;
}
RETCODE dbmnyzero(DBPROCESS *dbproc, DBMONEY *dest)
{
	return SUCCEED;
}
RETCODE dbmnymaxpos(DBPROCESS *dbproc, DBMONEY *dest)
{
	return SUCCEED;
}
RETCODE dbmnymaxneg(DBPROCESS *dbproc, DBMONEY *dest)
{
	return SUCCEED;
}
RETCODE dbmnyndigit(DBPROCESS *dbproc, DBMONEY *mnyptr,DBCHAR *value, DBBOOL *zero)
{
	return SUCCEED;
}
RETCODE dbmnyinit(DBPROCESS *dbproc,DBMONEY *mnyptr, int trim, DBBOOL *negative)
{
	return SUCCEED;
}
RETCODE dbmnydown(DBPROCESS *dbproc,DBMONEY *mnyptr, int divisor, int *remainder)
{
	return SUCCEED;
}
RETCODE dbmnyinc(DBPROCESS *dbproc,DBMONEY *mnyptr)
{
	return SUCCEED;
}
RETCODE dbmnydec(DBPROCESS *dbproc,DBMONEY *mnyptr)
{
	return SUCCEED;
}
RETCODE dbmnyminus(DBPROCESS *dbproc,DBMONEY *src, DBMONEY *dest)
{
	return SUCCEED;
}
RETCODE dbmny4minus(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest)
{
	return SUCCEED;
}
RETCODE dbmny4zero(DBPROCESS *dbproc, DBMONEY4 *dest)
{
	return SUCCEED;
}
RETCODE dbmny4add(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *sum)
{
	return SUCCEED;
}
RETCODE dbmny4sub(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *diff)
{
	return SUCCEED;
}
RETCODE dbmny4mul(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *prod)
{
	return SUCCEED;
}
RETCODE dbmny4divide(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *quotient)
{
	return SUCCEED;
}
RETCODE dbmny4cmp(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2)
{
	return SUCCEED;
}
RETCODE dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2)
{
	return SUCCEED;
}
RETCODE dbdatecrack(DBPROCESS *dbproc, DBDATEREC *dateinfo, DBDATETIME *datetime)
{
	return SUCCEED;
}
void dbrpwclr(LOGINREC *login)
{
}
RETCODE dbrpwset(LOGINREC *login, char *srvname, char *password, int pwlen)
{
	return SUCCEED;
}
int dbspid(DBPROCESS *dbproc)
{
	return 0;
}
RETCODE dbsetuserdata(DBPROCESS *dbproc, BYTE *ptr)
{
	return SUCCEED;
}
BYTE *dbgetuserdata(DBPROCESS *dbproc)
{
	return NULL;
}
RETCODE dbsetversion(DBINT version)
{
	return SUCCEED;
}
RETCODE dbmnycopy(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest)
{
	return SUCCEED;
}
RETCODE dbcanquery(DBPROCESS *dbproc)
{
	return SUCCEED;
}
RETCODE dbfreebuf(DBPROCESS *dbproc)
{
	return SUCCEED;
}
RETCODE dbclropt(DBPROCESS *dbproc,int option, char *param)
{
	return SUCCEED;
}
DBBOOL dbisopt(DBPROCESS *dbproc,int option, char *param)
{
	return TRUE;
}
DBINT DBCURROW(DBPROCESS *dbproc)
{
	return 0;
}
int DBCURCMD(DBPROCESS *dbproc)
{
	return 0;
}
RETCODE DBMORECMDS(DBPROCESS *dbproc)
{
	return SUCCEED;
}
int dbrettype(DBPROCESS *dbproc,int retnum)
{
	return 0;
}
int dbstrlen(DBPROCESS *dbproc)
{
	return 0;
}
RETCODE dbstrcpy(DBPROCESS *dbproc, int start, int numbytes, char *dest)
{
	return SUCCEED;
}
RETCODE dbsafestr(DBPROCESS *dbproc,char *src, DBINT srclen, char *dest, DBINT destlen, int quotetype)
{
	return SUCCEED;
}
char *dbprtype(int token)
{
	return NULL;
}
DBBINARY *dbtxtimestamp(DBPROCESS *dbproc, int column)
{
	return NULL;
}
DBBINARY *dbtxptr(DBPROCESS *dbproc,int column)
{
	return NULL;
}
RETCODE dbwritetext(DBPROCESS *dbproc,char *objname, DBBINARY *textptr,DBTINYINT textptrlen, DBBINARY *timestamp, DBBOOL log, DBINT size, BYTE *text)
{
	return SUCCEED;
}
STATUS dbreadtext(DBPROCESS *dbproc, void *buf, DBINT bufsize)
{
	return SUCCEED;
}
RETCODE dbmoretext(DBPROCESS *dbproc, DBINT size, BYTE *text)
{
	return SUCCEED;
}
void dbrecftos(char *filename)
{
}
char *dbversion()
{
	return NULL;
}
RETCODE dbsetdefcharset(char *charset)
{
	return SUCCEED;
}
RETCODE dbreginit(
      DBPROCESS *dbproc,
      DBCHAR *procedure_name,
      DBSMALLINT namelen )
{
      return SUCCEED;
}
RETCODE dbreglist(DBPROCESS *dbproc)
{
      return SUCCEED;
}
RETCODE dbregparam(
      DBPROCESS    *dbproc,
      char         *param_name,
      int          type,
      DBINT        datalen,
      BYTE         *data )
{
      return SUCCEED;
}
RETCODE dbregexec(
      DBPROCESS      *dbproc,
      DBSMALLINT    options)
{
	return SUCCEED;
}
char      *dbmonthname(DBPROCESS *dbproc,char *language,int monthnum,DBBOOL shortform)
{
char *shortmon[] = {"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
char *longmon[] = {"January","February","March","April","May","June","July","August","September","October","November","December"};

	if (shortform)
		return shortmon[monthnum-1];
	else 
		return longmon[monthnum-1];
}
char      *dbname(DBPROCESS *dbproc)
{
	return NULL;
}

